@@ -1,7 +1,7 @@
 /*
  balloon.js -- a DHTML library for balloon tooltips
 
- $Id: balloon.js,v 1.13 2009/03/08 15:16:46 sheldon_mckay Exp $
+ $Id: balloon.js,v 1.9 2008/11/03 01:48:04 sheldon_mckay Exp $
 
  See http://www.gmod.org/wiki/index.php/Popup_Balloons
  for documentation.
@@ -47,13 +47,12 @@ var tooltipIsSuppressed;
 // This is constructor that is called to initialize the Balloon object  //
 //////////////////////////////////////////////////////////////////////////
 var Balloon = function () {
-  // Cursor tracking enabled by default
+
+  // Get default configuration from balloon.config.js
+  BalloonConfig(this);
+
+  // Cursor track enabled by default
   this.trackCursor = true;
-  
-  // Cursor tracking halts after one of these vertical
-  // or horizontal thresholds are reached
-  this.stopTrackingX = 100;
-  this.stopTrackingY = 50;
 
   // Track the cursor every time the mouse moves
   document.onmousemove = this.setActiveCoordinates;
@@ -81,12 +80,7 @@ var Balloon = function () {
 // This is the function that is called on mouseover.  It has a built-in //
 // delay time to avoid balloons popping up on rapid mouseover events    //
 //////////////////////////////////////////////////////////////////////////
-Balloon.prototype.showTooltip = function(evt,caption,sticky,width,height) {
-  // If the objext is not configured by now, fall back to default
-  if (!this.configured) {
-    BalloonConfig(this,'GBubble');
-  }
-
+Balloon.prototype.showTooltip = function(evt,caption,sticky,width) {
   // Awful IE bug, page load aborts if the balloon is fired
   // before the page is fully loaded.
   if (this.isIE() && document.readyState.match(/complete/i)) {
@@ -103,21 +97,10 @@ Balloon.prototype.showTooltip = function(evt,caption,sticky,width,height) {
     return false;
   }
 
-  // We use 1-100 scale for opacity internally
-  if (this.opacity && this.opacity < 1) {
-    this.opacity = parseInt(parseFloat(this.opacity) * 100);
-  }
-  else if (this.opacity && this.opacity == 1) {
-    this.opacity = 100;
-  }
-  else if (!this.opacity) {
-    this.opacity == 100;
-  }
-
   // Sorry Konqueror, no fade-in or translucency for you!
   if (this.isKonqueror()) {
     this.allowFade = false;
-    this.opacity   = 100;
+    this.opacity   = null;
   }
 
   // With IE, fading and translucency are not very compatible
@@ -139,21 +122,15 @@ Balloon.prototype.showTooltip = function(evt,caption,sticky,width,height) {
   }
 
   // Don't fire on mouseover if a non-sticky balloon is visible
-  if (balloonIsVisible && !balloonIsSticky && mouseOver) {
-    return false;
-  }
+  if (balloonIsVisible && !balloonIsSticky && mouseOver) return false;
 
   // Don't start a non-sticky balloon if a sticky one is visible
-  if (balloonIsVisible && balloonIsSticky && !sticky) {
-    return false;
-  }
-
+  if (balloonIsVisible && balloonIsSticky && !sticky) return false;
+  
   // Ignore repeated firing of mouseover->mouseout events on 
   // the same element (Safari)
   var el = this.getEventTarget(evt);
-  if (sticky && mouseOver && this.isSameElement(el,this.currentElement)) {
-    return false;
-  }  
+  if (sticky && mouseOver && this.isSameElement(el,this.currentElement)) return false;
   this.firingElement = el;
 
   // A new sticky balloon can erase an old one
@@ -164,13 +141,14 @@ Balloon.prototype.showTooltip = function(evt,caption,sticky,width,height) {
     var override = balloonIsSticky && !balloonIsVisible;
     Balloon.prototype.hideTooltip(override)
   }
-  if (!mouseOver) {
-    el.onmouseup  = function() {return false};
-  }
+  if (!mouseOver) el.onmouseup  = function() {return false};
   el.onmouseout = closeBalloon;
-  
+
   balloonIsSticky = sticky;
 
+  // force balloon width and/or height if requested
+  this.width  = width;
+
   this.hideTooltip();
 
   // request the contents synchronously (ie wait for result)
@@ -181,28 +159,28 @@ Balloon.prototype.showTooltip = function(evt,caption,sticky,width,height) {
     return false;
   }
 
-  this.width  = width;
-  this.height = height;
-  this.actualWidth = null;
-
-  // make sure old balloons are removed
-  this.cleanup();
-
   // Put the balloon contents and images into a visible (but offscreen)
   // element so they will be preloaded and have a layout to 
   // calculate the balloon dimensions
-  this.container = document.createElement('div');
-  this.container.id = 'container';
-  document.body.appendChild(this.container);
-  this.setStyle(this.container,'position','absolute');
-  this.setStyle(this.container,'top',-8888);
-  this.setStyle(this.container,'font-family',this.fontFamily);
-  this.setStyle(this.container,'font-size',this.fontSize);
+  if (!this.container) {
+    this.container = document.createElement('div');
+    document.body.appendChild(this.container);
+    this.setStyle(this.container,'position','absolute');
+    this.setStyle(this.container,'top',-8888);
+    this.setStyle(this.container,'display','inline');
+    this.setStyle(this.container,'z-index',2);
+    this.setStyle(this.container,'color',this.fontColor);
+    this.setStyle(this.container,'font-family',this.fontFamily);
+    this.setStyle(this.container,'font-size',this.fontSize);
+  }
+  else {
+    this.setStyle(this.container,'display','inline');
+  }
+
   this.container.innerHTML = unescape(this.currentHelpText);
-  
+
   // make sure balloon image path is complete
   if (this.images) {
-
     // main background image
     this.balloonImage  = this.balloonImage  ? this.images +'/'+ this.balloonImage  : false;
     this.ieImage       = this.ieImage       ? this.images +'/'+ this.ieImage       : false;
@@ -222,9 +200,8 @@ Balloon.prototype.showTooltip = function(evt,caption,sticky,width,height) {
   // handled properly by IE < 6.  Also, if opacity is set to
   // < 1 (translucent balloons), any version of IE does not
   // handle the image properly.
-  // Google chrome is a bit dodgey too
   // If there is an IE image provided, use that instead.
-  if (this.ieImage && (this.isIE() || this.isChrome())) {
+  if (this.ieImage && this.isIE()) {
     if (this.isOldIE() || this.opacity || this.allowFade) {    
       this.balloonImage = this.ieImage;
     }
@@ -251,20 +228,17 @@ Balloon.prototype.showTooltip = function(evt,caption,sticky,width,height) {
   currentBalloonClass = this;
 
   // Capture coordinates for mousedown or click
-  if (!mouseOver) {
-    this.setActiveCoordinates(evt);
-  }
+  if (!mouseOver) this.setActiveCoordinates(evt);
 
   // Remember which event started this
   this.currentEvent = evt;
 
-  // prevent interaction with gbrowse drag and drop
+  // prevent interaction with drag and drop
   evt.cancelBubble  = true;
 
   // Make delay time short for onmousedown
   var delay = mouseOver ? this.delayTime : 1;
   this.timeoutTooltip = window.setTimeout(this.doShowTooltip,delay);
-  this.pending = true;
 }
 
 
@@ -327,22 +301,17 @@ Balloon.prototype.doShowTooltip = function() {
 
   // do we have a cursor position?
   if (!(self.activeTop && self.activeRight)) {
-//     self.setActiveCoordinates();
+    self.setActiveCoordinates();
   }
 
-
   // balloon orientation
   var vOrient = self.activeTop > pageMid ? 'up' : 'down';
   var hOrient = self.activeRight > pageCen ? 'left' : 'right';
   
   // get the preloaded balloon contents
   var helpText = self.container.innerHTML;
-  self.actualWidth = self.getLoc(self.container,'width') + 10;
-  self.parent.removeChild(self.container);
-  var wrapper = document.createElement('div');
-  wrapper.id = 'contentWrapper';
-  self.contents.appendChild(wrapper);
-  wrapper.innerHTML = helpText;
+
+  self.contents.innerHTML = helpText;
 
   // how and where to draw the balloon
   self.setBalloonStyle(vOrient,hOrient,pageWidth,pageLeft);
@@ -353,14 +322,10 @@ Balloon.prototype.doShowTooltip = function() {
   }
 
   balloonIsVisible = true;
-  self.pending = false;  
-
+  
   // in IE < 7, hide <select> elements
   self.showHide();
 
-  self.startX = self.activeLeft;
-  self.startY = self.activeTop;
-
   self.fade(0,self.opacity,self.fadeIn);
 }
 
@@ -383,11 +348,6 @@ Balloon.prototype.addCloseButton = function () {
     document.body.appendChild(closeButton);
   }
 
-  // I have no idea why
-  if (self.isIE()) {
-    BalloonLeft = BalloonLeft - 5;
-  }
-
   self.setStyle(closeButton,'top',balloonTop);
   self.setStyle(closeButton,'left',BalloonLeft);
   self.setStyle(closeButton,'display','inline');
@@ -401,9 +361,7 @@ Balloon.prototype.makeBalloon = function() {
   var self = currentBalloonClass;
 
   var balloon = document.getElementById('balloon');
-  if (balloon) {
-    self.cleanup();
-  }
+  if (balloon) self.parent.removeChild(balloon);
 
   balloon = document.createElement('div');
   balloon.setAttribute('id','balloon');
@@ -419,14 +377,17 @@ Balloon.prototype.makeBalloon = function() {
     if (parts[i] == 'contents') self.contents = child;
     self.parts.push(child);
   }
-  //self.parts.push(balloon);
 
-  if (self.displayTime)  {
+  if (balloonIsSticky) {
+    self.setStyle('contents','margin-right',10); 
+  }
+  else if (self.displayTime)  {
     self.timeoutAutoClose = window.setTimeout(this.hideTooltip,self.displayTime);
   }
   return balloon;
 }
 
+
 Balloon.prototype.setBalloonStyle = function(vOrient,hOrient,pageWidth,pageLeft) {
   var self = currentBalloonClass;
   var balloon = self.activeBalloon;
@@ -434,50 +395,43 @@ Balloon.prototype.setBalloonStyle = function(vOrient,hOrient,pageWidth,pageLeft)
   if (typeof(self.shadow) != 'number') self.shadow = 0;
   if (!self.stem) self.stemHeight = 0;
 
+  // If width and/or height are specified, harden the
+  // balloon at those dimensions, but not if the space needed
+  // is less the the space that would be used.
+  if (self.width) {
+    var widthUsed = self.getLoc('contents','width');
+    var newWidth = widthUsed > self.width ? self.width : widthUsed;
+    self.setStyle('contents','width',newWidth);
+  }
+  if (self.height) {
+    var heightUsed = YAHOO.util.Dom.getStyle('contents','height');
+    var newHeight = heightUsed > self.height ? self.height : heightUsed;
+    self.setStyle('contents','height',newHeight+(2*self.padding));
+  }
+
   var fullPadding   = self.padding + self.shadow;
   var insidePadding = self.padding;
-  var outerWidth    = self.actualWidth + fullPadding;
-  var innerWidth    = self.actualWidth;  
 
   self.setStyle(balloon,'position','absolute');
   self.setStyle(balloon,'top',-9999);
   self.setStyle(balloon,'z-index',1000000);
 
-  if (self.height) {
-    self.setStyle('contentWrapper','height',self.height-fullPadding);
-  }
-
-  if (self.width) {
-    self.setStyle(balloon,'width',self.width);  
-    innerWidth = self.width - fullPadding;
-    if (balloonIsSticky) {
-      innerWidth -= self.closeButtonWidth;
-    }
-    self.setStyle('contentWrapper','width',innerWidth);
-  }
-  else {
-    self.setStyle(balloon,'width',outerWidth);
-    self.setStyle('contentWrapper','width',innerWidth);
-  }
-
-  // not too big...
-  if (!self.width && self.maxWidth && outerWidth > self.maxWidth) {
-    self.setStyle(balloon,'width',self.maxWidth);
-    self.setStyle('contentWrapper','width',self.maxWidth-fullPadding);
-  }
-  // not too small...
-  if (!self.width && self.minWidth && outerWidth < self.minWidth) {
-    self.setStyle(balloon,'width',self.minWidth);
-    self.setStyle('contentWrapper','width',self.minWidth-fullPadding);
-  }
-
   self.setStyle('contents','z-index',2);
   self.setStyle('contents','color',self.fontColor);
   self.setStyle('contents','font-family',self.fontFamily);
   self.setStyle('contents','font-size',self.fontSize);
-  self.setStyle('contents','background','url('+self.balloonImage+') top left no-repeat');
-  self.setStyle('contents','padding-top',fullPadding);
-  self.setStyle('contents','padding-left',fullPadding);
+
+  // Fading and transparency in IE is hard!  Argh!
+  if (self.isIE() && !self.allowFade) { 
+    self.setStyle('contents','background','url('+self.balloonImage+') top left no-repeat');
+    self.setStyle('contents','padding-top',fullPadding);
+    self.setStyle('contents','padding-left',fullPadding);
+  }
+  else {
+    self.setStyle(balloon,'background','url('+self.balloonImage+') top left no-repeat');
+    self.setStyle(balloon,'padding-top',fullPadding);
+    self.setStyle(balloon,'padding-left',fullPadding);
+  }  
 
   self.setStyle('bottomRight','background','url('+self.balloonImage+') bottom right no-repeat');
   self.setStyle('bottomRight','position','absolute');
@@ -529,9 +483,6 @@ Balloon.prototype.setBalloonStyle = function(vOrient,hOrient,pageWidth,pageLeft)
       self.setStyle(stem,'top',0-height);
       self.setStyle(stem,'left',self.shadow);
     }
-    if (self.fadeOK && self.isIE()) {
-      self.parts.push(stem);
-    }
   }
 
   if (self.allowFade) {
@@ -552,13 +503,19 @@ Balloon.prototype.setBalloonStyle = function(vOrient,hOrient,pageWidth,pageLeft)
     self.setStyle(balloon,'left',activeLeft);
   }
 
+  if (!self.width) {
+    var width = self.getLoc('contents','width');
+    if (width > self.maxWidth) width = self.maxWidth + 50;
+    if (width < self.minWidth) width = self.minWidth;
+    self.setStyle(balloon,'width',width);
+  }
+
   // oversized contents? Scrollbars for sticky balloons, clipped for non-sticky
   var overflow = balloonIsSticky ? 'auto' : 'hidden';
-  self.setStyle('contentWrapper','overflow',overflow);
+  self.setStyle('contents','overflow',overflow);
 
-  // a bit of room for the closebutton
   if (balloonIsSticky) {
-    self.setStyle('contentWrapper','margin-right',self.closeButtonWidth);
+    self.setStyle('contents','padding-right',self.closeButtonWidth);
   }
 
   // Make sure the balloon is not offscreen horizontally.
@@ -569,14 +526,10 @@ Balloon.prototype.setBalloonStyle = function(vOrient,hOrient,pageWidth,pageLeft)
   var scrollBar     = 20;
 
   if (hOrient == 'right' && balloonRight > (self.pageRight - fullPadding)) {
-    var width = (self.pageRight - balloonLeft) - fullPadding - scrollBar;
-    self.setStyle(balloon,'width',width);
-    self.setStyle('contentWrapper','width',width-fullPadding);
+    self.setStyle(balloon,'width',(self.pageRight - balloonLeft) - fullPadding - scrollBar);
   }
   else if (hOrient == 'left' && balloonLeft < (self.pageLeft + fullPadding)) {
-    var width = (balloonRight - self.pageLeft) - fullPadding;
-    self.setStyle(balloon,'width',width);
-    self.setStyle('contentWrapper','width',width-fullPadding);
+    self.setStyle(balloon,'width',(balloonRight - self.pageLeft) - fullPadding);
   }
 
   // Get the width/height for the right and bottom outlines
@@ -586,14 +539,9 @@ Balloon.prototype.setBalloonStyle = function(vOrient,hOrient,pageWidth,pageLeft)
   // IE7 quirk -- look for unwanted overlap cause by an off by 1px error
   var vOverlap = self.isOverlap('topRight','bottomRight');
   var hOverlap = self.isOverlap('bottomLeft','bottomRight');
-  if (vOverlap) {
-    self.setStyle('topRight','height',balloonHeight-vOverlap[1]);
-  }
-  if (hOverlap) {
-    self.setStyle('bottomLeft','width',balloonWidth-hOverlap[0]);
-  }
+  if (vOverlap) self.setStyle('topRight','height',balloonHeight-vOverlap[1]);
+  if (hOverlap) self.setStyle('bottomLeft','width',balloonWidth-hOverlap[0]);
 
-  // vertical position of the balloon
   if (vOrient == 'up') {
     var activeTop = self.activeTop - balloonHeight;
     self.setStyle(balloon,'top',activeTop);
@@ -603,16 +551,17 @@ Balloon.prototype.setBalloonStyle = function(vOrient,hOrient,pageWidth,pageLeft)
     self.setStyle(balloon,'top',activeTop);
   }
 
+
   // Make sure the balloon is vertically contained in the window
   var balloonTop    = self.getLoc(balloon,'y1');
-  var balloonBottom = self.height ? balloonTop + self.height : self.getLoc(balloon,'y2');
+  var balloonBottom = self.getLoc(balloon,'y2');
   var deltaTop      = balloonTop < self.pageTop ? self.pageTop - balloonTop : 0;
   var deltaBottom   = balloonBottom > self.pageBottom ? balloonBottom - self.pageBottom : 0;
 
   if (vOrient == 'up' && deltaTop) {
     var newHeight = balloonHeight - deltaTop;
     if (newHeight > (self.padding*2)) {
-      self.setStyle('contentWrapper','height',newHeight-fullPadding);
+      self.setStyle('contents','height',newHeight);
       self.setStyle(balloon,'top',self.pageTop+self.padding);
       self.setStyle(balloon,'height',newHeight);
     }
@@ -620,26 +569,11 @@ Balloon.prototype.setBalloonStyle = function(vOrient,hOrient,pageWidth,pageLeft)
   if (vOrient == 'down' && deltaBottom) {
     var newHeight = balloonHeight - deltaBottom - scrollBar;
     if (newHeight > (self.padding*2) + scrollBar) {
-      self.setStyle('contentWrapper','height',newHeight-fullPadding);
+      self.setStyle('contents','height',newHeight);
       self.setStyle(balloon,'height',newHeight);
     }
   }
 
-  // If we have an iframe, make sure it fits properly
-  var iframe = balloon.getElementsByTagName('iframe');
-  if (iframe[0]) {
-    iframe = iframe[0];
-    var w = self.getLoc('contentWrapper','width');
-    if (balloonIsSticky && !this.isIE()) {
-      w -= self.closeButtonWidth;
-    }
-    var h = self.getLoc('contentWrapper','height');
-    self.setStyle(iframe,'width',w);
-    self.setStyle(iframe,'height',h);
-    self.setStyle('contentWrapper','overflow','hidden');
-  }
-
-  // Make edges match the main balloon body
   self.setStyle('topRight','height', self.getLoc(balloon,'height'));
   self.setStyle('bottomLeft','width', self.getLoc(balloon,'width'));
 
@@ -647,7 +581,6 @@ Balloon.prototype.setBalloonStyle = function(vOrient,hOrient,pageWidth,pageLeft)
   self.vOrient = vOrient;
 }
 
-
 // Fade method adapted from an example on 
 // http://brainerror.net/scripts/javascript/blendtrans/
 Balloon.prototype.fade = function(opacStart, opacEnd, millisec) {
@@ -673,12 +606,24 @@ Balloon.prototype.setOpacity = function(opc) {
 
   var o = parseFloat(opc/100);
 
-  // opacity handled differently for IE
-  var parts = self.isIE() ? self.parts : [self.activeBalloon];
+  // For fading in IE, just the contents can fade
+  // otherwise, the whole balloon
+  if (self.fadeOK) {
+    var el = self.isIE() ? self.contents : self.activeBalloon;
+    self.doOpacity(o,opc,el);
+    return false;
+  }
 
-  var len = parts.length;
+  var els = new Array;
+  if (self.isIE()) {
+    els.push(self.parts);
+  }
+  else {
+    els.push(self.activeBalloon);
+  }
+  var len = els.length;
   for (var i=0;i<len;i++) {
-    self.doOpacity(o,opc,parts[i]);
+    self.doOpacity(o,opc,els[i]);
   }
 }
 
@@ -699,52 +644,38 @@ Balloon.prototype.doOpacity = function(op,opc,el) {
   self.setStyle(el,'KhtmlOpacity',op);
 }
 
-Balloon.prototype.hideTooltip = function(override) { 
+Balloon.prototype.hideTooltip = function(override) {
   // some browsers pass the event object == we don't want it
   if (override && typeof override == 'object') override = false;
   if (balloonIsSticky && !override) return false;
 
   var self = currentBalloonClass;
-  Balloon.prototype.showHide(1);
-  Balloon.prototype.cleanup();
+  var b = document.getElementById('balloon');
+  var c = document.getElementById('closeButton');
 
   if (self) {
     window.clearTimeout(self.timeoutTooltip);
     window.clearTimeout(self.timeoutFade);
     window.clearTimeout(self.timeoutAutoClose);
+    b = b || self.activeBalloon;
     if (balloonIsSticky) {
       self.currentElement = null;
     }
-    self.startX = 0;
-    self.startY = 0;
   }
 
+  if (b) {
+    Balloon.prototype.setStyle(b,'display','none');
+  }
+  if (c) {
+    Balloon.prototype.setStyle(c,'display','none');
+  }
+
+  Balloon.prototype.showHide(1);
+
   balloonIsVisible = false;
   balloonIsSticky  = false;
 }
 
-// Garbage collection
-Balloon.prototype.cleanup = function() {
-  var self = currentBalloonClass;
-  var body;
-  if (self) {
-    body = self.parent   ? self.parent 
-         : self.parentID ? document.getElementById(self.parentID) || document.body
-         : document.body;
-  }
-  else {
-    body = document.body;
-  }
-
-  var bubble = document.getElementById('balloon');
-  var close  = document.getElementById('closeButton');
-  var cont   = document.getElementById('container');
-  if (bubble) { body.removeChild(bubble) } 
-  if (close)  { body.removeChild(close)  }
-  if (cont)   { body.removeChild(cont)   }
-}
-
-
 // this function is meant to be called externally to clear
 // any open balloons
 hideAllTooltips = function() {
@@ -762,64 +693,50 @@ hideAllTooltips = function() {
 Balloon.prototype.setActiveCoordinates = function(evt) {
   var self = currentBalloonClass;
   if (!self) {
-    return true;
+    return false;
   }
   var evt = evt || window.event || self.currentEvent;
   if (!evt) {
-    return true;
+    return false;
   }
 
   // avoid silent NaN errors
-  self.hOffset = self.hOffset || 1;
-  self.vOffset = self.vOffset || 1;
-  self.stemHeight = self.stem && self.stemHeight ? (self.stemHeight|| 0) : 0;
-
-  var scrollTop  = 0;
-  var scrollLeft = 0;
-  if (self.isIE()) {
-    var scrollTop  = window.pageYOffset || document.documentElement.scrollTop  || 0; 
-    var scrollLeft = window.pageXOffset || document.documentElement.scrollLeft || 0;
-  }
+  self.hOffset = self.hOffset || 10;
+  self.vOffset = self.vOffset || 10;
+  self.stemHeight = self.stemHeight || 0;
 
   var XY = self.eventXY(evt);
-  adjustment   = self.hOffset < 20 ? 10 : 0;
-  self.activeTop    = scrollTop  + XY[1] - adjustment - self.vOffset - self.stemHeight;
-  self.activeLeft   = scrollLeft + XY[0] - adjustment - self.hOffset;
-  self.activeRight  = scrollLeft + XY[0];
-  self.activeBottom = scrollTop  + XY[1] + self.vOffset + 2*adjustment;
+  var adjustment    = self.hOffset < 20 ? 10 : 0;
+  self.activeTop    = XY[1] - adjustment - self.vOffset - self.stemHeight;
+  self.activeLeft   = XY[0] - adjustment - self.hOffset;
+  self.activeRight  = XY[0] + adjustment + self.hOffset;
+  self.activeBottom = XY[1] + adjustment + self.vOffset + self.stemHeight;
 
   // dynamic positioning but only if the balloon is not sticky
   // and cursor tracking is enabled
   if (balloonIsVisible && !balloonIsSticky && self.trackCursor) {
-    var deltaX = Math.abs(self.activeLeft - self.startX);
-    var deltaY = Math.abs(self.activeTop - self.startY);
+    var b = self.activeBalloon;
+    var bwidth  = self.getLoc(b,'width');
+    var bheight = self.getLoc(b,'height');
+    var btop    = self.getLoc(b,'y1');
+    var bleft   = self.getLoc(b,'x1');
 
-    if (deltaX > self.stopTrackingX || deltaY > self.stopTrackingY) {
-      self.hideTooltip();
+    if (self.hOrient == 'right') {
+      self.setStyle(b,'left',self.activeRight);
     }
-    else {
-      var b = self.activeBalloon;
-      var bwidth  = self.getLoc(b,'width');
-      var bheight = self.getLoc(b,'height');
-      var btop    = self.getLoc(b,'y1');
-      var bleft   = self.getLoc(b,'x1');
-
-      if (self.hOrient == 'right') {
-        self.setStyle(b,'left',self.activeRight);
-      }
-      else if (self.hOrient == 'left') {
-        self.setStyle(b,'right',null);
-        var newLeft = self.activeLeft - bwidth;
-        self.setStyle(b,'left',newLeft);
-      }
-
-      if (self.vOrient == 'up') {
-        self.setStyle(b,'top',self.activeTop - bheight);
-      }
-      else if (self.vOrient == 'down') {
-        self.setStyle(b,'top',self.activeBottom);
-      }
+    else if (self.hOrient == 'left') {
+      self.setStyle(b,'right',null);
+      var newLeft = self.activeLeft - bwidth;
+      self.setStyle(b,'left',newLeft);
     }
+
+    if (self.vOrient == 'up') {
+      self.setStyle(b,'top',self.activeTop - bheight);
+    }
+    else if (self.vOrient == 'down') {
+      self.setStyle(b,'top',self.activeBottom);
+    }
+
   }
 
   return true;
@@ -831,9 +748,7 @@ Balloon.prototype.setActiveCoordinates = function(evt) {
 Balloon.prototype.eventXY = function(event) {
   var XY = new Array(2);
   var e = event || window.event;
-  if (!e) {
-    return false;
-  }
+
   if (e.pageX || e.pageY) {
     XY[0] = e.pageX;
     XY[1] = e.pageY;
@@ -858,22 +773,9 @@ Balloon.prototype.getEventTarget = function(event) {
 
 
 Balloon.prototype.setStyle = function(el,att,val) {
-  if (!el) { 
-    return false;
-  }
-  if (typeof(el) != 'object') {
-    el = document.getElementById(el);
-  }
-  if (!el) {
-    return false;
-  }
-  
-  if (val && att.match(/left|top|bottom|right|width|height|padding|margin/)) {
-    val = new String(val);
-    if (!val.match(/auto/)) {
-      val += 'px';
-    }
-  }
+  if (!el) return false;
+  if (val && att.match(/left|top|bottom|right|width|height|padding|margin/)) val += 'px'; 
+  if (typeof(el) != 'object') el = document.getElementById(el);
 
   // z-index does not work as expected
   if (att == 'z-index') {
@@ -898,9 +800,7 @@ Balloon.prototype.getLoc = function(el,request) {
     case ('width')  : return (parseInt(region.right)  - parseInt(region.left));
     case ('height') : return (parseInt(region.bottom) - parseInt(region.top));
     case ('region') : return region; 
-  }
-
-  return region;
+ }
 }
 
 // We don't know if numbers are overridden with strings
@@ -926,9 +826,8 @@ Balloon.prototype.showHide = function(visible) {
 
   // IE z-index bug fix (courtesy of Lincoln Stein)
   if (self.isOldIE()) {
-    var balloonContents = document.getElementById('contentWrapper');
-    if (!visible && balloonContents) {
-      var balloonSelects = balloonContents.getElementsByTagName('select');
+    if (!visible) {
+      var balloonSelects = document.getElementById('contents').getElementsByTagName('select');
       var myHash = new Object();
       for (var i=0; i<balloonSelects.length; i++) {
         var id = balloonSelects[i].id || balloonSelects[i].name;
@@ -1116,10 +1015,5 @@ Balloon.prototype.isOldIE = function() {
 
 // test for Konqueror
 Balloon.prototype.isKonqueror = function() {
-  return navigator.userAgent.toLowerCase().indexOf( 'konqueror' ) != -1;
+  return navigator.userAgent.indexOf( 'Konqueror' ) != -1;
 }
-
-// and Google chrome
-Balloon.prototype.isChrome = function() {
-  return navigator.userAgent.toLowerCase().indexOf('chrome') > -1;
-}
\ No newline at end of file
